#Medición biométrica

Desde los primeros trabajos desarrollados por Darwin hace más de 100 años, en su obra acerca de la expresión de las emociones en animales y humanos \cite{darwin1965expression} la propuesta evolucionista ha permitido identificar las emociones básicas que componen el conjunto de las expresiones humanas, indagando así en la universalidad de estas, su significado y su reconocimiento en distintas culturas \cite{fernandez2007expresion}. En este orden de ideas, se ha dado una creciente integración de los campos de la anatomía y fisiología del sistema nervioso y su correlación psicológica, considerado esto último crucial para comprender en detalle la conducta emocional en el reconocimiento y la expresión de emociones \cite{Phillips_2003}. Hoy por hoy, desde el campo de las neurociencias se realizan diferentes investigaciones para tener una mejor  comprensión sobre la localización y el funcionamiento de áreas cerebrales comprometidas en la experiencia, reconocimiento y expresión emocional \cite{rainville2006basic}.

En la actualidad existe un conjunto amplio de investigaciones relacionadas con el estudio de diferentes parámetros periféricos ante la activación emocional, tales como la actividad muscular facial, frecuencia cardiaca y respiratoria, así como la respuesta galvánica de la piel \cite{hagemann2003central}. Los resultados de estas investigaciones han concluido que que existe un patrón de activación del sistema nervioso autónomo que es característico de cada una de las emociones básicas reconocidas hasta hoy, encontrándose una alta correlación en la discriminación de emociones que se obtiene, a través de medidas fisiológicas autonómicas como presión sanguínea, conductancia de la piel y tono vagal \cite{christie2004autonomic}. Así también, como una forma de integrar la conceptualización psicológica de las emociones y su medición fisiológica, \cite{rainville2006basic} han caracterizado la actividad cardiorrespiratoria que distingue la experiencia de las emociones básicas  (rabia, tristeza, alegría y miedo) pudiéndose identificar mediante la tipificación de los tipos de frecuencia cardiaca y el cambio en los patrones respiratorios observados durante la presentación de estímulos emocionales.


Lo anterior, ha permitido que el concepto de biometría adquiera importancia para el desarrollo de investigaciones en el campo de las neurociencias esecialmente. El concepto biometría proviene de las palabras bio (vida) y metría (medida), y con ello se hace referencia a todo equipo biométrico que mide e identifica alguna característica propia de la persona \cite{jain2006biometrics, osorio2010sistemas}. En este sentido, los sistemas biométricos incluyen un dispositivo de captación y un software biométrico que interpreta la muestra física y la transforma en una secuencia numérica \cite{watson2007user}. La biometría la definen como una rama de la matemáticas y la estadísticas que se ocupa del análisis de datos biológicos y que comprende temas como población, medidas físicas, tratamientos de enfermedades y otros por el estilo \cite{jain2006biometrics}. La medición biométrica se ha venido estudiando desde tiempo atrás y es considerada en la actualidad como el método ideal de identificación humana.

Algunas de las modalidades biométricas empleadas en la actualidad son las siguientes:

## Seguimiento ocular (_eye-tracking_)

Los ojos se cuentan dentro de los órganos humanos más importantes. De hecho los ojos son la principal "interfaz" entre el entorno y el cerebro humano. Por lo tanto, no es una sorpresa que el sistema encargado de la visión humana sea fisiológica y neurológicamente complicado, requiriendo aspectos fisiológicos y comportamentales. El uso de los ojos para llevar a cabo la identificación humana en los métodos biométricos tiene una larga tradición que incluye algoritmos de reconocimiento de patrones del iris bien establecidos y el escaneo de retina \cite{kasprowski2004eye}.

\cite{kasprowski2004eye} describe que cuando un sujeto mira un objeto, la imagen se proyecta sobre la retina la cual está compuesta de células fotosensibles que convierten la luz en señales, las cuales son transmitidas al cerebro a través del nervio óptico. La distribución en la retina de estas células fotosensibles es desigual, siendo más densa en el centro que en la periferia. Esa disposición hace que varie la agudeza de la visual, encontrando una visión más detallada cuando el objeto de interés se encuentra en el centro de la retina. Esta zona se llama fóvea y cubre alrededor de dos grados de ángulo visual \cite{kasprowski2004eye}. Los movimientos oculares se hacen para reorientar el ojo de manera que la imagen cae sobre la fóvea así el más alto nivel de detalle puede ser extraído. Por está razón es posible definir un "punto de vista", un punto exacto que una persona está mirando en un momento determinado. Así, para habilitar el cerebro y recibir la imagen en tiempo real, el sistema oculomotor tiene que ser muy rápido y preciso, dejando el control de los ojos directamente al cerebro \cite{holmqvist2011eye}.

Si bien en cuanto a los movimientos oculares se refiere, existen dos indicadores que resultan de interés en el marco de la investigación biométrica, estos son la fijación de la mirada en un punto fijo en el espacio (el cual se puede tomar como atención a dicho punto) y la midriasis:

* **Fijación de la mirada:** La fijación, sucede cuando los ojos están mirando un objeto de interés por un período de tiempo. Durante ese periodo, la imagen que se proyecta sobre la fóvea y se analiza por el cerebro. La fijación estándar dura de alrededor de 200 a 300 milisegundos, dependiendo de la complejidad de una imagen observada. Después de una fijación, los ojos se mueven rápidamente a otro punto de vista, otra fijación, este movimiento rápido se denomina una sacada; las sacadas difieren en longitud, pero siempre son muy rápidas \cite{kasprowski2004eye, salvucci2000identifying}.

* **Midriasis:** El término latino "_mydriasis_", denomina la dilatación patológica de la pupila, bien sea por una respuesta fisiológica normal o patológica. Esta dilatación puede ser causada, como bien fue señalado previamente, por respuesta fisiológica natural frente a la luz o por estímulos sensoriales y/o emocionales \cite{fresneda1989historia}.

Considerando lo anterior, el seguimiento ocular es una técnica mediante la cual se mide el movimiento del ojo de una persona \cite{holmqvist2011eye}, así el investigador conoce tanto lo que la persona está observando en un momento dado, así como la secuencia descrita mientras se desplazan de un lugar a otro. El seguimiento ocular cuenta con aplicaciones en HCI (Human Computered Interaction) ayudando a los investigadores a entender el procesamiento de la información visual, basado en pantalla y los factores que pueden afectar su usabilidad en las interfaces de sistemas \cite{Poole}.

En el mercado existen diversidad de software y equipos basados en el _eye-tracking_, muchos de ellos utilizan gafas como medio de obtención de datos, estás detectan el movimiento de los ojos y la dilatación de la pupila del usuario, los datos son llevados a una computadora la cual los procesa en un software y extrae las información importante, convirtiéndola en un mapa de "zonas calientes" o mapas de puntos, que reflejan la zona en la cual la persona crea una fijación, brindando además el grado de dilatación de la pupila en el momento de la toma \cite{holmqvist2011eye, duchowski2007eye}. Últimamente se han desarrollado softwares avanzados, en los cuales, mediante el uso de cámaras de alta definición, las cuales permanecen en posición fija grabando los ojos del usuario, se puede realizar el mismo procesamiento de datos, sin el uso de las gafas \cite{duchowski2002breadth, myers1991eye}.

En la actualidad, el _eye-tracking_ es una de las técnicas biométricas que más empleadas, dada la gran variedad de equipos y usos con los que cuentan. Con motivo de esto, se ha combinado su uso con otras tecnologías mencionadas en este documento, por ejemplo, para  analizar el comportamiento del sujeto en un ambiente rodeado de estímulos, se usa electroencefalografía junto con seguimiento ocular para saber exactamente qué está produciendo las reacciones cerebrales. Asimismo, algunas consultoras en marketing (iMotions, www.imotionsglobal.com) están intentando utilizar métricas como la frecuencia de parpadeo para deducir las emociones del sujeto en cada momento \cite{benito2011neuromarketing}. Muchas investigaciones has sido desarrolladas contando con el uso del _eye-tracking_:

* **Design, User Experience, and Usability: Design Philosophy, Methods** \cite{marcus2013design}: Cuenta con un compendio de artículos investigativos, haciendo hincapié en el diseño, la experiencia de usuario y la usabilidad de equipos y softwares, gran parte de estos desarrollos se han realizado usando tecnología de seguimiento ocular.
* **Eye Tracking in Practice** \cite{renshaw2007eye}: Analiza las ventajas y desventajas que posee el seguimiento ocular, y aclara dudas sobre sus posibles aportes y usabilidad, en distintos campos de acción.
* **Do we track what we see? Common versus independent processing for motion perception and smooth pursuit eye movements: A review** \cite{spering2011we}: Enfoca la invesigación de seguimiento ocular en la interacción entre la percepción y el propósito que posee el observador. 
* **Current trends in eye-tracking research** \cite{horsley2014current}: Al igual que \cite{marcus2013design}, genera un estado del arte sobre casos aplicados del uso de _eye-tracking_, en campos como: sistemas visuales, EEG data , marketing y aplicaciones sociales, educación, entre otros.

Esto ha ocasionado que este sea una de las tecnología biométricas con mas desarrollo y de mayor reconocimiento en los últimos años.


## Electromiografía (EMG)

Se puede hablar de actividad eléctrica muscular cuando las neuronas motoras, localizadas en los lóbulos cerebrales, transmiten señales eléctricas a tavés del sistema nervioso hacia los músculos, las cuales generan la contracción y relajación de los mismos, estás señales eléctricas son medidas a su vez en el electromiograma (EMG). Está actividad eléctrica muscular es controlada por el cerebro, bien puede ser por el sistema simpático o parasipático.  (http://www.mayoclinic.org/tests-procedures/electroconvulsive-therapy/basics/definition/prc-20014183) 

La señal de EMG es una representación del campo de potencial eléctrico generado por la despolarización de la membrana de fibra muscular (sarcolema) \cite{merletti2004electromyography}. Consta de la aplicación de pequeños electrodos de bajo voltaje (a manera de agujas) en el territorio muscular que se desea estudiar para medir su respuesta y conectividad entre los diferentes electrodos. Mide la actividad eléctrica generada por los músculos (generalmente de los músculos faciales, asociados a respuestas emocionales involuntarias). Usualmente, estos movimientos no suelen ser detectados a simple vista, y reflejan la valencia positiva o negativa de la reacción a los estímulos (gusto/disgusto), sobretodo estímulos visuales, auditivos, olfativos y gustativos \cite{benito2011neuromarketing}. Igualmente, la EMG proporciona un acceso sencillo a los procesos fisiológicos responsables de la fuerza muscular, de producir el movimiento y llevar a cabo las innumerables funciones que nos permiten interactuar con el mundo que nos rodea \cite{de1997use}. 

Se ha identificado como parte de esta modalidad biométrica el **Facial Action Recognition System (FACS)** como un método de la observación de las expresiones faciales en donde a través  de la grabación de la cara del sujeto se realiza una codificación de los músculos que se activan durante la exposición un estímulo. El más conocido y utilizado, fue desarrollado por Paul Ekman \cite{ekman1978manual}, quien postuló seis emociones primarias, cada una de las cuales posee un contenido distintivo junto con una única expresión facial. Estas manifestaciones emocionales también se conocen como las llamadas emociones básicas, de aparente carácter universal y comprenden alegría (1), tristeza (2), miedo (3), disgusto (4), sorpresa (5) y la ira (6) \cite{fasel2003automatic}. 
En la actualidad, existe software informático que permite la codificación automática de las expresiones faciales \cite{azcarate2005automatic, salah2010communication}, algunas compañías comercializan dichos paquetes de software para su uso en investigación de mercados. (Affectiva, www.affectiva.com; Thirdsight, www.thirdsight.co; Noldus, www.noldus.com; nViso, www.nviso.ch) \cite{benito2011neuromarketing, fasel2003automatic}. El sistema propuesto por \cite{azcarate2005automatic}, presenta un sistema de reconocimiento de las emociones a través de expresiones faciales que aparecen en secuencias de vídeo en directo y grabadas. El sistema se basa en el seguimiento de la Deformación del Volumen por Trozos de Bézier (PBVD, por sus siglas en inglés) \cite{tao1998connected} y se ha ampliado con un detector de caras Haar para localizar inicialmente el rostro humano de forma automática. Así, resulta conveniente para aplicaciones futuras, puesto que no es necesario que la persona permanezca inmóvil, siendo de provecho para la realización de actividades prácticas.

## Actividad electrodérmica (EDA)

La conductancia de la piel, también conocida como la respuesta galvánica de la piel (GSR), respuesta electrodérmica (EDR), reflejo psicogalvánico (PGR), la respuesta de conductancia de la piel (SCR) o el nivel de conductancia de la piel (SCL), es un método para medir la conductancia eléctrica de la piel, que varía con su nivel de humedad. Esto es de interés porque las glándulas sudoríparas son controlados por el sistema nervioso simpático, por lo conductancia de la piel se utiliza como una indicación de la excitación psicológica o fisiológica \cite{dashboardgalvanic, widacki2015discoverers}.

Esta tecnología, fue descubierta por Feré en 1881, basada en el principio de que la resistencia de la piel a la electricidad varía con la activación (arousal) experimentada por el usuario \cite{benito2011neuromarketing}. El arousal simpático genera una activación mayor de las glándulas sudoríparas, lo cual genera una incremento en la humedad, provocando una mayor actividad electrodérmica, alterando las propiedades bioeléctricas de la piel \cite{widacki2015discoverers, boucsein2012electrodermal}.

Lo estudio con EDA se utiliza ampliamente en la investigación psicológica, debido a su bajo costo y alta utilidad. A menudo, la respuesta galvánica de la piel se combina con el registro de la frecuencia cardíaca, frecuencia respiratoria y la presión arterial debido a que son todas las variables dependientes autonómicas. Además, la SCR es altamente sensible a las emociones en algunas personas, entre ellas el miedo, la ira y la sorpresa las cuales están entre las reacciones que pueden producir respuestas similares en la conductancia de la piel \cite{carlson2010physiology, dashboardgalvanic}.

Dentro de los equipos idenificados el más popular es el galvanómetro de cuerda, formado por un filamento delgado de cuarzo recubierto de plata que pasa entre 2 eletroimanes. La corriente eléctrica pasa a través del filamento y produce un movimiento que proyecta una sombra, que se magnifica y se registra. El galvanómetro fue el precursor de la electrocardiografía creando así una nueva rama de la medicina e incluso una nueva industria. Einthoven logró tal perfección técnica que muchos electrocardiógrafos modernos producen grabaciones de tan alta calidad \cite{rivera2008einthoven, fisch2000centennial}.

El galvanómetro ha sido ampliamente usado con fines investigativos en el campo de la medición de emociones desde 1907, es un medidor de tono emocional agudo el cual escapa del control de la voluntad. Este instrumento registra las condiciones emocionales en las esferas subconscientes o inconscientes \cite{peterson1907galvanometer, jones1935galvanic, widacki2015discoverers}. En la actualidad muchos dispositivos de biofeedback utilizan conductancia de la piel para medir y presentar la respuesta al estrés de una persona con el objetivo de ayudar al usuario a controlar su ansiedad. Además de esto, existen algunas restriciones, por ejemplo la temperatura, la humedad y la ingesta de medicamentos pueden afectar las mediciones, conduciendo a resultados inconsistentes. Por último, las respuestas galvánicas de la piel tienen un retraso de 1-3 segundos. Combinados, estos factores muestran la complejidad de la relación entre la GSR y la actividad simpática del sujeto \cite{pflanzer2013galvanic}.

## Frecuencia cardiaca

La frecuencia cardíaca o ritmo cardiaco, es el número de contracciones o pulsaciones por unidad de tiempo que realiza el corazón para bombear la sangre al cuerpo. Se expresa en pulsaciones por minuto en las arterias periféricas y en latidos por minuto (lat/min) para el corazón. La medición del pulso se puede efectuar en distintos puntos, pero lo más habitual es que se lo mida en la muñeca, en el cuello o en el tórax. Esta puede variar sus parámetros normales por condiciones fisiológicas (esfuerzo físico, cambios fisiológicos, entre otros) o por cambios provocados por el medio ambiente (estímulos emocionales, condiciones de temperatura y presión, reacción a agentes externos, oxigeno presente en el medio, entre otros) \cite{berne2008berne}. Debido a la importancia que posee la frecuencia cardiaca, existen gran variedad de equipos que se han venido desarrollando a lo largo de la historía.

Willem Einthoven (1860–1927), es el creador reconocido del electrocardiógrafo (ECG), ganador del Premio Nobel en 1924  "por el descubrimiento del mecanismo del electrocardiograma" \cite{rivera2008einthoven, sourkes1967nobel}. El ECG no es solo el más antiguo, de hecho, aún 100 años después de su introducción, junto con el galvanómetro, continua siendo el más usado en los procedimientos cardiovasculares. No es invasivo, simple para registrar, altamente reproducible y se puede aplicar en serie. El equipo y el costo del registro son mínimos \cite{fisch2000centennial}. 

Otro quipo es conocido como Holter permite realizar el monitoreo a distancia de parámetros fisiológicos, en particular de la actividad cardíaca. La grabadora Holter es una máquina de registro, prácticamente continua y capaz de grabar durante un largo período de tiempo las señales detectadas por medio de electrodos aplicados al paciente \cite{faisandier1997programmable}.

Recientemente, debido al auge de los teléfonos móviles y a las aplicaciones diseñadas para estos, ha venido en aumento su uso para la medición de indicadores fisiológicos, sobretodo la frecuencia cardíaca, en este caso funcionan usando la cámara y el flash (de ser posible), para calcular el porcentaje hemoglobina oxigenada debido a que la absorción de la luz es diferente en cada una de ellas. De esa forma calcula exactamente la frecuencia cardíaca, de forma algo similar a como lo hacen dispositivos médicos convencionales \cite{scully2012physiological}.

Si bien la frecuencia cardiaca no nos da indicios directos de la emocionalidad de la persona, existen evidencias que brindan una guía con respecto a su interpretación relacionado a la emocionalidad \cite{rainville2006basic}, muchas veces, se usa como técnica de soporte a otras de las relacionadas en este documento.

## Presión sanguínea

Es la tensión ejercida por la sangre sobre las paredes de los vasos sanguíneos cuando esta pasa a través de ellos, constituye uno de los signos vitales mas importantes. La presión de la sangre disminuye a medida que la sangre se mueve a través de arterias, arteriolas, vasos capilares, y venas; el término presión sanguínea generalmente se refiere a la presión arterial, es decir, la presión ejercida sobre las arterias del sistema circulatorio \cite{braunwald2003primary, machuca2003guia}.  La variación de la presión arterial puede corresponder a diversos factores, que se resumen en dos grupos: los factores internos (causados por el cuerpo, entre ellos la acticidad física) y los factores externos (aquellos causados por estímulos externos: emocionales \cite{rainville2006basic}, climatológicos, patógenos, alergenos, entre otros) \cite{braunwald2003primary}.

La toma de la presión arterial es una de las técnicas que más se realiza a lo largo de la vida de una persona, e igualmente resulta ser una de las técnicas de atención primaria o especializada más habitualmente empleadas, aportando al personal médico un dato imprescindible para saber cómo una persona se encuentra en relación a su supervivencia (generalmente asociado a su función circulatoria), cumpliendo una misión fundamental en la medicina preventiva \cite{salisbury1963blood, braunwald2003primary}. Entre los equipos usados para este fin, se puede encontrar:

1. **Esfigmomanómetro**: también llamado esfingmanómetro o tensiómetro, es un instrumento médico empleado para la medición indirecta de la presión arterial proporcionando, por lo general, la medición en milímetros de mercurio (mmHg o torr) \cite{rela1998fisica}. Existen diversos esfigmomanómetros en la actualidad. Los tradicionales de columna de mercurio, los aneroides (de aguja empujada por resortes interiores, en lugar de la columna de mercurio) y los digitales. Cada uno de estos sistemas posee características propias, siendo los más precisos los de columna de mercurio (desde comienzos del siglo XXI en desuso en Europa). La precisión de los esfigmomanómetros de dial circular depende de su radio; los digitales poseen menos precisión que los de mercurio, pero son automáticos y fáciles de operar \cite{braunwald2003primary, Holubarsch_1999}.
2. **MAPA**: el monitoreo ambulatorio de presión arterial (MAPA) es una metodología que ha contribuido a un mayor conocimiento de la fisiología tensional y de las variaciones diarias de la tensión, es la más adecuada para casos en los que se requiera un registro constante de los datos para hallar variaciones o alteraciones que pueden ser causados por la medición tradicional u otras causas \cite{bendersky2000monitoreo, penaz1989automatic}. 
3. **Oscilométricos**: es un esfigmanómetro compuesto por una columna de mercurio, en el que se mide la presión sanguínea haciendo uso de un manómetro de mercurio. Adicionalmete, el quipo tiene en el interior un sensor de presión electrónico (transductor) para detectar el flujo de sangre. \cite{cromer1996fisica, beevers2001blood, salisbury1963blood}.

## Respiración

La respiración es un proceso fisiológico por el cual los organismos vivos toman oxígeno del medio circundante y desprenden dióxido de carbono. El término respiración, utilizado en un contexto médico, se refiere a la respiración externa o sea a la captación de oxígeno y la eliminación de anhídrido carbónico entre el aire del ambiente y la sangre en los capilares pulmonares \cite{parra2004paciente}.

La mecánica pulmonar se describe principalmente por dos movimientos escenciales, la inhalación y la exhalación. La primera, se debe a la contracción y aplanamiento del diafragma (músculo en forma de cúpula que separa el tórax del abdomen) si el abdomen se encuentra relajado, esta contracción hace que este sobresalga hacia el exterior, expandiendo el volumen del cuerpo. El aumento del volumen provoca una caída de la presión en el pecho, que causa la expansión de los pulmones. Cuando el diafragma se relaja, el aire sale en gran parte debido a la elasticidad del pulmón. La exhalación sigue a la relajación de diafragma y los músculos abdominales, pero puede aumentarse por la acción descendente de los músculos abdominales en la caja torácica \cite{parra2004paciente, patton2015anatomy}. Este patrón (inhalación y exhalación) puede variar con el miedo en anticipación a la necesidad, y así mismo, con la ansiedad \cite{rainville2006basic}. También se ve afectada por la pérdida de elasticidad pulmonar debido a la edad o a una enfermedad pulmonar, de la expansión abdominal por la obesidad, o de la capacidad muscular para resistir la expansión o para estirar la caja torácica hacia abajo \cite{patton2015anatomy}. Entre los equipos usados para este fin, se puede encontrar: 

1. Espirómetro: producto de uso sanitario usado en medicina para medir el volúmen y capacidad del pulmón. Consiste en un sistema de recolección de aire (usualmente fuelle o campana) y de un sistema de inscripción montado a un soporte el cual se desplaza a la velocidad deseada, al añadir un potenciómetro, se genera una señal proporcional al desplazamiento de la campana o fuelle, lo que permite trasformar la señal mecánica en eléctrica \cite{kiraly2005history}.

2. Pletismografía: es un método basado en la medición de cambios de presión y volumen que se utiliza para medir parámetros orientados al diagnóstico de enfermedades pulmonares o cardiovasculares. La pletismografía se desarrolla en una cabina totalmente sellada, la cual funciona mediante la aplicación de la ley de Boyle en la que a la persona se le pide que respire contra resistencia, tras realizar los cálculos correspondientes, se conoce el volumen de gas en los pulmones \cite{sanchez2004bases}.

## Actividad cerebral

Las diferentes investigaciones muestras que el cerebro produce impulsos eléctricos que viajan a través de las neuronas. Estos impulsos eléctricos producen ritmos que son conocidos como ondas cerebrales. Los impulsos eléctricos son información que viaja de neurona a neurona haciendo uso de cientos de miles de ellas para lograr transportarse y ejecutar una función determinada **(ref)**. La actividad de las ondas cerebrales puede ser observada a través de la electroencefalografía (EEG) o la Resonancia Magnética Funcional (fMRI).

La electroencefalografía (EEG) es una tecnología no invasiva y silenciosa que a través de electrodos colocados en el cuero cabelludo puede registrar las diferencias de potencial que producen miles de neuronas de tal forma que se puede tener una idea de que zonas del cerebro están produciendo mayor actividad \cite{berne2008berne,benito2011neuromarketing,miranda2015darpa}. En cuanto a su cobertura de imágen, posee un rango de detección mayor que el fMRI, pero con resolución espacial limitada, aún así no ofrece datos de las partes profundas del cerebro. La técnica posee costos menores a las otras herramientas neuroloógicas y permite movilidad e interacción con el medio. Desafortunadamente, posee muchas conexiones (cables) lo cual podría dificultad la movilidad del usuario \cite{benito2011neuromarketing,davidson1990approach}.

Una práctica común con esta tecnología es medir la asimetría de actividad entre las regiones izquierda y derecha del córtex frontal \cite{davidson1990approach}. La literatura científica al respecto sugiere que una actividad superior en la región izquierda se asocia bien con estados emocionales positivos, bien con la intención de acercarse a un objeto \cite{harmon2003clarifying}.

Por su parte, la Resonancia Magnética Funcional (fMRI) es una técnica que permite la obtención de imágenes del cerebro durante la realización de una tarea planificada, permitiendo la detección e identificación de áreas del cerebro durante su actividad, diferenciándola de las imágenes tradicionales de resonancia magnética que solo aportan una visión anatómica del cerebro \cite{rosales2003resonancia}. La fMRI funciona midiendo, mediante magnetismo, los cambios en los niveles de oxigenación cerebral de la sangre en la zona a estudiar, que a su vez se relacionan con la actividad presente \cite{benito2011neuromarketing}.

Según \cite{rosales2003resonancia}, la fMRI utiliza los fundamentos que enlaza la actividad neuronal con el metabolismo y el flujo sanguíneo. Es capaz de registrar cambios hemodinámicos en el cerebro que acompañan la activación neuronal y permite la evaluación de regiones encargadas de la sensorialidad, motricidad, cognición y procesos afectivos en cerebros normales y aún en aquellos que presentan anomalias. Su uso es necesario para obtener información sobre la actividad de las partes más internas del cerebro, como por ejemplo la Ínsula, la cual relaciona la intensidad que tiene el gusto/disgusto por aquello a lo que se está observando o el Córtex Cingulado Anterior (ACC), que permite medir el grado de contradicción entre estímulos percibido por la persona \cite{benito2011neuromarketing}.

La fMRI, se caracteriza por no ser invasiva, aún así, requiere de inmovilidad por parte del sujeto, además de que el dispositivo necesario es de gran tamaño e inamovible, por lo tanto requiere de un lugar fijo para su ubicación y la realización del estudio. Suele tener un lento procesamiento de imágenes, pero con gran definición, sumado a esto su alto costo de adquisición \cite{benito2011neuromarketing}, lo convierte en una opción poco atractiva para la realización de estudios en sector industrial.

A través de tecnologías como la Electroencefalografía (EEG) o la Resonancia Magnética Funcional (fMRI), las «respuestas» de los entrevistados a distintos estímulos son «leídas» directamente de su actividad cerebral \cite{benito2011neuromarketing}.

Lo descrito hasta este punto hace referencia a la medición de de indicadores que pueden ser catalogados como individuales, pero se cuenta con una serie de equipos que permiten una medición simultanea dos o más de estos indicadores. En la revisión de la literatura se identificaron el polígrafo y el BioHarness.

## Polígrafo

A pesar de que se desconoce el creador del polígrafo parece que su utilización para fines científicos, comenzó en 1895 con el italiano Cesare Lombroso, quien estudió la relación entre los cambios en el sistema cardiovascular y la reacción del cuerpo con la mentira. Para esto utilizó los parámetros de ritmo cardíaco y presión sanguínea. Posteriormente, en 1902, James Mackenzie (cardiólogo), inventó un sistema eléctrico para medir al mismo tiempo la presión arterial y el pulso yugular, al que llamó polígrafo. Aún así, fue Leonard Keeler, del Departamento de Policía de Berkeley (California, EE.UU.) quién en 1938 contribuyó de manera destacable a la creación del polígrafo moderno, fabricando un modelo compacto denominado _Keeler Compact Polygraph_, polígrafo de tres canales que imprimía los resultados en papel, es así como muchos consideran que fue Keeler el inventor del polígrafo \cite{widacki2015discoverers, anta2012deteccion}.

Los polígrafos a menudo se utilizan como detectores de mentiras, porque la frecuencia cardíaca, la frecuencia respiratoria, la presión arterial y la sudoración, poseen un significado autónomo que no se pueden modificar de manera consciente \cite{pflanzer2013galvanic, dashboardgalvanic}, aún así, no se les puede denominar por completo "detector de mentiras", dado que este solo mide las alteraciones fisiológicas en las personas; en concreto, cuatro \cite{anta2012deteccion}:

* La presión arterial y el ritmo cardiaco: mediante un manguito colocado alrededor del brazo.
* La respiración: por medio de sendos tubos (neumógrafos) colocados en el pecho y zona abdominal.
* La respuesta galvánica o conductancia de la piel: mediante sensores colocados en las yemas de los dedos, se mide la sudoración.

## BioHarness

El BioHarness, puede comparar la información sobre múltiples variables fisiológicas y de actividad integradas, que se pueden evaluar en tiempo real o después de la toma de datos. El BioHarness™ mide simultáneamente cinco variables, entre ellas: tasa cardíaca, frecuencia respiratoria, temperatura de la piel, los movimientos y la postura, estos pueden ser monitoreados de forma inalámbrica en tiempo real o descargar desde el dispositivo después de la actividad \cite{johnstone2012bioharness}. 